@@ -139,8 +139,9 @@ ensure_texture (GstVaapiWindowEGL * window, guint width, guint height)
 
   texture = gst_vaapi_texture_egl_new (GST_VAAPI_WINDOW_DISPLAY (window),
       GL_TEXTURE_2D, GL_RGBA, width, height);
-  gst_vaapi_texture_replace (&window->texture, texture);
-  gst_vaapi_texture_replace (&texture, NULL);
+  gst_mini_object_replace ((GstMiniObject **) & window->texture,
+      (GstMiniObject *) texture);
+  gst_mini_object_replace ((GstMiniObject **) & texture, NULL);
   return window->texture != NULL;
 }
 
@@ -281,10 +282,13 @@ gst_vaapi_window_egl_finalize (GObject * object)
 {
   GstVaapiWindowEGL *const window = GST_VAAPI_WINDOW_EGL (object);
 
-  egl_context_run (window->egl_window->context,
-      (EglContextRunFunc) do_destroy_objects, window);
+  if (window->egl_window) {
+    egl_context_run (window->egl_window->context,
+        (EglContextRunFunc) do_destroy_objects, window);
+  }
+
   gst_vaapi_window_replace (&window->window, NULL);
-  gst_vaapi_texture_replace (&window->texture, NULL);
+  gst_mini_object_replace ((GstMiniObject **) & window->texture, NULL);
 
   G_OBJECT_CLASS (gst_vaapi_window_egl_parent_class)->finalize (object);
 }
@@ -382,7 +386,7 @@ gst_vaapi_window_egl_resize (GstVaapiWindow * window, guint width, guint height)
 static gboolean
 do_render_texture (GstVaapiWindowEGL * window, const GstVaapiRectangle * rect)
 {
-  const GLuint tex_id = GST_VAAPI_OBJECT_ID (window->texture);
+  const GLuint tex_id = GST_VAAPI_TEXTURE_ID (window->texture);
   EglVTable *const vtable = window->egl_vtable;
   GLfloat x0, y0, x1, y1;
   GLfloat texcoords[4][2];
@@ -505,20 +509,6 @@ gst_vaapi_window_egl_render (GstVaapiWindow * window, GstVaapiSurface * surface,
       (EglContextRunFunc) do_upload_surface, &args) && args.success;
 }
 
-static gboolean
-gst_vaapi_window_egl_render_pixmap (GstVaapiWindow * window,
-    GstVaapiPixmap * pixmap, const GstVaapiRectangle * src_rect,
-    const GstVaapiRectangle * dst_rect)
-{
-  const GstVaapiWindowClass *const klass =
-      GST_VAAPI_WINDOW_GET_CLASS (GST_VAAPI_WINDOW_EGL_GET_PROXY (window));
-
-  if (!klass->render_pixmap)
-    return FALSE;
-  return klass->render_pixmap (GST_VAAPI_WINDOW_EGL_GET_PROXY (window), pixmap,
-      src_rect, dst_rect);
-}
-
 static void
 gst_vaapi_window_egl_class_init (GstVaapiWindowEGLClass * klass)
 {
@@ -534,7 +524,6 @@ gst_vaapi_window_egl_class_init (GstVaapiWindowEGLClass * klass)
   window_class->set_fullscreen = gst_vaapi_window_egl_set_fullscreen;
   window_class->resize = gst_vaapi_window_egl_resize;
   window_class->render = gst_vaapi_window_egl_render;
-  window_class->render_pixmap = gst_vaapi_window_egl_render_pixmap;
 }
 
 static void
